Module path_sensitive

Module path_sensitive 

Path-sensitive taint analysis

This module analyzes taint flow separately for each execution path through a function’s CFG. This enables detecting vulnerabilities where only some branches lack sanitization.

Structs

PathAnalysisResult
Result of analyzing a single path
PathSensitiveResult
Result of path-sensitive analysis
PathSensitiveTaintAnalysis
Path-sensitive taint analysis
SanitizerCall
SinkCall
SourceCall

Enums

TaintState
Taint state for a variable