pub struct TaintFlow {
pub source: TaintSource,
pub sink: TaintSink,
pub sanitized: bool,
pub propagation_path: Vec<String>,
}Expand description
Represents a complete taint flow from source to sink
Fields
source: TaintSourcesink: TaintSinksanitized: boolpropagation_path: Vec<String>Implementations
Sourceimpl TaintFlow
impl TaintFlow
Sourcepub fn to_finding(
&self,
rule_metadata: &RuleMetadata,
function_name: &str,
function_sig: &str,
span: Option<SourceSpan>,
) -> Finding
pub fn to_finding( &self, rule_metadata: &RuleMetadata, function_name: &str, function_sig: &str, span: Option<SourceSpan>, ) -> Finding
Convert this taint flow into a Finding for reporting