Finding

Struct Finding 

pub struct Finding {
Show 16 fields pub rule_id: String, pub rule_name: String, pub severity: Severity, pub confidence: Confidence, pub message: String, pub function: String, pub function_signature: String, pub evidence: Vec<String>, pub span: Option<SourceSpan>, pub cwe_ids: Vec<String>, pub fix_suggestion: Option<String>, pub code_snippet: Option<String>, pub exploitability: Exploitability, pub exploitability_score: f32, pub code_context: CodeContext, pub filter_reason: Option<String>,
}

Fields

rule_id: Stringrule_name: Stringseverity: Severityconfidence: Confidence

Confidence level of this specific finding

message: Stringfunction: Stringfunction_signature: Stringevidence: Vec<String>span: Option<SourceSpan>cwe_ids: Vec<String>

CWE identifiers for this finding

fix_suggestion: Option<String>

Actionable fix suggestion

code_snippet: Option<String>

Code snippet showing the vulnerable code

exploitability: Exploitability

CVSS-like exploitability metrics

exploitability_score: f32

Computed exploitability score (0.0 - 3.9)

code_context: CodeContext

Code context where this finding was detected (production, test, example, etc.)

filter_reason: Option<String>

Reason for filtering if this finding was excluded from primary results

Implementations

Source

impl Finding

pub fn new( rule_id: impl Into<String>, rule_name: impl Into<String>, severity: Severity, message: impl Into<String>, function: impl Into<String>, function_signature: impl Into<String>, evidence: Vec<String>, span: Option<SourceSpan>, ) -> Self

Create a new finding with default confidence and optional fields

pub fn with_confidence(self, confidence: Confidence) -> Self

Set confidence level

pub fn with_cwe(self, cwe_ids: Vec<String>) -> Self

Set CWE identifiers

pub fn with_fix(self, fix: impl Into<String>) -> Self

Set fix suggestion

pub fn with_snippet(self, snippet: impl Into<String>) -> Self

Set code snippet

pub fn with_exploitability(self, exploitability: Exploitability) -> Self

Set exploitability metrics and compute score

pub fn with_code_context(self, context: CodeContext) -> Self

Set code context (production, test, example, benchmark)

pub fn with_filter_reason(self, reason: impl Into<String>) -> Self

Mark this finding as filtered with a reason

pub fn is_non_production(&self) -> bool

Returns true if this finding is from non-production code